@@ -1,3 +1,13 @@
+#!/usr/bin/env ruby
+#
+# Put description here
+#
+# 
+# 
+# 
+#
+
+require 'swig_assert'
 require 'abstract_signature'
 
 include Abstract_signature
@@ -9,7 +19,13 @@ include Abstract_signature
 
 exceptionRaised = false
 begin
-  Abstract_foo.new
+  foo = Abstract_foo.new
+  begin
+    foo.meth(1)
+  rescue RuntimeError 
+    # here we are using directors
+    exceptionRaised = true
+  end
 rescue NameError
   exceptionRaised = true
 rescue TypeError
@@ -17,7 +33,7 @@ rescue TypeError
   # TypeError: allocator undefined for Abstract_signature::Abstract_foo
 	exceptionRaised = true
 ensure
-  raise RuntimeError unless exceptionRaised
+  swig_assert( "exceptionRaised", binding)
 end
 
 #
@@ -27,7 +43,13 @@ end
 
 exceptionRaised = false
 begin
-  Abstract_bar.new
+  bar = Abstract_bar.new
+  begin
+    bar.meth(1)
+  rescue RuntimeError 
+    # here we are using directors
+    exceptionRaised = true
+  end
 rescue NameError
   exceptionRaised = true
 rescue TypeError
@@ -35,6 +57,6 @@ rescue TypeError
   # TypeError: allocator undefined for Abstract_signature::Abstract_bar
 	exceptionRaised = true
 ensure
-  raise RuntimeError unless exceptionRaised
+  swig_assert( "exceptionRaised", binding)
 end
 
