@@ -7,10 +7,9 @@
  * Expands a template into a specialized version.   
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_templ_c[] = "$Header: /cvsroot/swig/SWIG/Source/CParse/templ.c,v 1.33 2006/11/01 23:54:49 wsfulton Exp $";
+char cvsroot_templ_c[] = "$Id: templ.c 10540 2008-06-21 15:23:02Z wsfulton $";
 
 #include "swig.h"
-#include "swigkeys.h"
 #include "cparse.h"
 
 static int template_debug = 0;
@@ -19,16 +18,16 @@ static int template_debug = 0;
 String *baselists[3];
 
 void SwigType_template_init() {
-  baselists[0] = k_baselist;
-  baselists[1] = k_protectedbaselist;
-  baselists[2] = k_privatebaselist;
+  baselists[0] = "baselist";
+  baselists[1] = "protectedbaselist";
+  baselists[2] = "privatebaselist";
 }
 
 
 static void add_parms(ParmList *p, List *patchlist, List *typelist) {
   while (p) {
-    SwigType *ty = Getattr(p, k_type);
-    SwigType *val = Getattr(p, k_value);
+    SwigType *ty = Getattr(p, "type");
+    SwigType *val = Getattr(p, "value");
     Append(typelist, ty);
     Append(typelist, val);
     Append(patchlist, val);
@@ -41,7 +40,7 @@ void Swig_cparse_debug_templates(int x) {
 }
 
 /* -----------------------------------------------------------------------------
- * Swig_cparse_template_expand()
+ * cparse_template_expand()
  *
  * Expands a template node into a specialized version.  This is done by
  * patching typenames and other aspects of the node according to a list of
@@ -51,17 +50,18 @@ void Swig_cparse_debug_templates(int x) {
 static int cparse_template_expand(Node *n, String *tname, String *rname, String *templateargs, List *patchlist, List *typelist, List *cpatchlist) {
   static int expanded = 0;
   int ret;
-  String *nodeType = Getattr(n, k_nodetype);
+  String *nodeType;
   if (!n)
     return 0;
-  if (Getattr(n, k_error))
+  nodeType = nodeType(n);
+  if (Getattr(n, "error"))
     return 0;
 
-  if (StringEqual(nodeType, k_template)) {
+  if (Equal(nodeType, "template")) {
     /* Change the node type back to normal */
     if (!expanded) {
       expanded = 1;
-      Setattr(n, k_nodetype, Getattr(n, k_templatetype));
+      set_nodeType(n, Getattr(n, "templatetype"));
       ret = cparse_template_expand(n, tname, rname, templateargs, patchlist, typelist, cpatchlist);
       expanded = 0;
       return ret;
@@ -69,37 +69,37 @@ static int cparse_template_expand(Node *n, String *tname, String *rname, String
       /* Called when template appears inside another template */
       /* Member templates */
 
-      Setattr(n, k_nodetype, Getattr(n, k_templatetype));
+      set_nodeType(n, Getattr(n, "templatetype"));
       ret = cparse_template_expand(n, tname, rname, templateargs, patchlist, typelist, cpatchlist);
-      Setattr(n, k_nodetype, k_template);
+      set_nodeType(n, "template");
       return ret;
     }
-  } else if (StringEqual(nodeType, k_cdecl)) {
+  } else if (Equal(nodeType, "cdecl")) {
     /* A simple C declaration */
     SwigType *t, *v, *d;
     String *code;
-    t = Getattr(n, k_type);
-    v = Getattr(n, k_value);
-    d = Getattr(n, k_decl);
+    t = Getattr(n, "type");
+    v = Getattr(n, "value");
+    d = Getattr(n, "decl");
 
-    code = Getattr(n, k_code);
+    code = Getattr(n, "code");
 
     Append(typelist, t);
     Append(typelist, d);
     Append(patchlist, v);
     Append(cpatchlist, code);
 
-    if (Getattr(n, k_conversionoperator)) {
-      Append(cpatchlist, Getattr(n, k_name));
-      if (Getattr(n, k_symname)) {
-	Append(cpatchlist, Getattr(n, k_symname));
+    if (Getattr(n, "conversion_operator")) {
+      Append(cpatchlist, Getattr(n, "name"));
+      if (Getattr(n, "sym:name")) {
+	Append(cpatchlist, Getattr(n, "sym:name"));
       }
     }
 
-    add_parms(Getattr(n, k_parms), cpatchlist, typelist);
-    add_parms(Getattr(n, k_throws), cpatchlist, typelist);
+    add_parms(Getattr(n, "parms"), cpatchlist, typelist);
+    add_parms(Getattr(n, "throws"), cpatchlist, typelist);
 
-  } else if (StringEqual(nodeType, k_class)) {
+  } else if (Equal(nodeType, "class")) {
     /* Patch base classes */
     {
       int b = 0;
@@ -124,16 +124,16 @@ static int cparse_template_expand(Node *n, String *tname, String *rname, String
 	cn = nextSibling(cn);
       }
     }
-  } else if (StringEqual(nodeType, k_constructor)) {
-    String *name = Getattr(n, k_name);
-    if (!(Getattr(n, k_templatetype))) {
+  } else if (Equal(nodeType, "constructor")) {
+    String *name = Getattr(n, "name");
+    if (!(Getattr(n, "templatetype"))) {
       String *symname;
       String *stripped_name = SwigType_templateprefix(name);
       if (Strstr(tname, stripped_name)) {
 	Replaceid(name, stripped_name, tname);
       }
       Delete(stripped_name);
-      symname = Getattr(n, k_symname);
+      symname = Getattr(n, "sym:name");
       if (symname) {
 	stripped_name = SwigType_templateprefix(symname);
 	if (Strstr(tname, stripped_name)) {
@@ -142,11 +142,11 @@ static int cparse_template_expand(Node *n, String *tname, String *rname, String
 	Delete(stripped_name);
       }
       if (strchr(Char(name), '<')) {
-	Append(patchlist, Getattr(n, k_name));
+	Append(patchlist, Getattr(n, "name"));
       } else {
 	Append(name, templateargs);
       }
-      name = Getattr(n, k_symname);
+      name = Getattr(n, "sym:name");
       if (name) {
 	if (strchr(Char(name), '<')) {
 	  Clear(name);
@@ -159,48 +159,48 @@ static int cparse_template_expand(Node *n, String *tname, String *rname, String
 	  Delete(tmp);
 	}
       }
-      /* Setattr(n,k_symname,name); */
+      /* Setattr(n,"sym:name",name); */
     }
-    Append(cpatchlist, Getattr(n, k_code));
-    Append(typelist, Getattr(n, k_decl));
-    add_parms(Getattr(n, k_parms), cpatchlist, typelist);
-    add_parms(Getattr(n, k_throws), cpatchlist, typelist);
-  } else if (StringEqual(nodeType, k_destructor)) {
-    String *name = Getattr(n, k_name);
+    Append(cpatchlist, Getattr(n, "code"));
+    Append(typelist, Getattr(n, "decl"));
+    add_parms(Getattr(n, "parms"), cpatchlist, typelist);
+    add_parms(Getattr(n, "throws"), cpatchlist, typelist);
+  } else if (Equal(nodeType, "destructor")) {
+    String *name = Getattr(n, "name");
     if (name && strchr(Char(name), '<')) {
-      Append(patchlist, Getattr(n, k_name));
+      Append(patchlist, Getattr(n, "name"));
     } else {
       Append(name, templateargs);
     }
-    name = Getattr(n, k_symname);
+    name = Getattr(n, "sym:name");
     if (name && strchr(Char(name), '<')) {
       String *sn = Copy(tname);
-      Setattr(n, k_symname, sn);
+      Setattr(n, "sym:name", sn);
       Delete(sn);
     } else {
       Replace(name, tname, rname, DOH_REPLACE_ANY);
     }
-    /* Setattr(n,k_symname,name); */
-    Append(cpatchlist, Getattr(n, k_code));
-  } else if (StringEqual(nodeType, k_using)) {
-    String *uname = Getattr(n, k_uname);
+    /* Setattr(n,"sym:name",name); */
+    Append(cpatchlist, Getattr(n, "code"));
+  } else if (Equal(nodeType, "using")) {
+    String *uname = Getattr(n, "uname");
     if (uname && strchr(Char(uname), '<')) {
       Append(patchlist, uname);
     }
-    if (Getattr(n, k_namespace)) {
+    if (Getattr(n, "namespace")) {
       /* Namespace link.   This is nasty.  Is other namespace defined? */
 
     }
   } else {
     /* Look for obvious parameters */
     Node *cn;
-    Append(cpatchlist, Getattr(n, k_code));
-    Append(typelist, Getattr(n, k_type));
-    Append(typelist, Getattr(n, k_decl));
-    add_parms(Getattr(n, k_parms), cpatchlist, typelist);
-    add_parms(Getattr(n, k_kwargs), cpatchlist, typelist);
-    add_parms(Getattr(n, k_pattern), cpatchlist, typelist);
-    add_parms(Getattr(n, k_throws), cpatchlist, typelist);
+    Append(cpatchlist, Getattr(n, "code"));
+    Append(typelist, Getattr(n, "type"));
+    Append(typelist, Getattr(n, "decl"));
+    add_parms(Getattr(n, "parms"), cpatchlist, typelist);
+    add_parms(Getattr(n, "kwargs"), cpatchlist, typelist);
+    add_parms(Getattr(n, "pattern"), cpatchlist, typelist);
+    add_parms(Getattr(n, "throws"), cpatchlist, typelist);
     cn = firstChild(n);
     while (cn) {
       cparse_template_expand(cn, tname, rname, templateargs, patchlist, typelist, cpatchlist);
@@ -230,6 +230,10 @@ String *partial_arg(String *s, String *p) {
   return newarg;
 }
 
+/* -----------------------------------------------------------------------------
+ * Swig_cparse_template_expand()
+ * ----------------------------------------------------------------------------- */
+
 int Swig_cparse_template_expand(Node *n, String *rname, ParmList *tparms, Symtab *tscope) {
   List *patchlist, *cpatchlist, *typelist;
   String *templateargs;
@@ -249,25 +253,25 @@ int Swig_cparse_template_expand(Node *n, String *rname, ParmList *tparms, Symtab
     Delete(tmp);
   }
 
-  tname = Copy(Getattr(n, k_name));
+  tname = Copy(Getattr(n, "name"));
   tbase = Swig_scopename_last(tname);
 
   /* Look for partial specialization matching */
-  if (Getattr(n, k_partialargs)) {
+  if (Getattr(n, "partialargs")) {
     Parm *p, *tp;
-    ParmList *ptargs = SwigType_function_parms(Getattr(n, k_partialargs));
+    ParmList *ptargs = SwigType_function_parms(Getattr(n, "partialargs"));
     p = ptargs;
     tp = tparms;
     while (p && tp) {
       SwigType *ptype;
       SwigType *tptype;
       SwigType *partial_type;
-      ptype = Getattr(p, k_type);
-      tptype = Getattr(tp, k_type);
+      ptype = Getattr(p, "type");
+      tptype = Getattr(tp, "type");
       if (ptype && tptype) {
 	partial_type = partial_arg(tptype, ptype);
 	/*      Printf(stdout,"partial '%s' '%s'  ---> '%s'\n", tptype, ptype, partial_type); */
-	Setattr(tp, k_type, partial_type);
+	Setattr(tp, "type", partial_type);
 	Delete(partial_type);
       }
       p = nextSibling(p);
@@ -277,13 +281,13 @@ int Swig_cparse_template_expand(Node *n, String *rname, ParmList *tparms, Symtab
     Delete(ptargs);
   }
 
-  if (0) {
+  /*
     Parm *p = tparms;
     while (p) {
-      Printf(stdout, "tparm: '%s' '%s' '%s'\n", Getattr(p, k_name), Getattr(p, k_type), Getattr(p, k_value));
+      Printf(stdout, "tparm: '%s' '%s' '%s'\n", Getattr(p, "name"), Getattr(p, "type"), Getattr(p, "value"));
       p = nextSibling(p);
     }
-  }
+  */
 
   /*  Printf(stdout,"targs = '%s'\n", templateargs);
      Printf(stdout,"rname = '%s'\n", rname);
@@ -292,7 +296,7 @@ int Swig_cparse_template_expand(Node *n, String *rname, ParmList *tparms, Symtab
 
   /* Set the name */
   {
-    String *name = Getattr(n, k_name);
+    String *name = Getattr(n, "name");
     if (name) {
       Append(name, templateargs);
     }
@@ -301,25 +305,25 @@ int Swig_cparse_template_expand(Node *n, String *rname, ParmList *tparms, Symtab
 
   /* Patch all of the types */
   {
-    Parm *tp = Getattr(n, k_templateparms);
+    Parm *tp = Getattr(n, "templateparms");
     Parm *p = tparms;
     /*    Printf(stdout,"%s\n", ParmList_str_defaultargs(tp)); */
 
     if (tp) {
-      Symtab *tsdecl = Getattr(n, k_symsymtab);
+      Symtab *tsdecl = Getattr(n, "sym:symtab");
       while (p && tp) {
 	String *name, *value, *valuestr, *tydef, *tmp, *tmpr;
 	int sz, i;
 	String *dvalue = 0;
 	String *qvalue = 0;
 
-	name = Getattr(tp, k_name);
-	value = Getattr(p, k_value);
-	tydef = Getattr(p, k_typedef);
+	name = Getattr(tp, "name");
+	value = Getattr(p, "value");
+	tydef = Getattr(p, "typedef");
 
 	if (name) {
 	  if (!value)
-	    value = Getattr(p, k_type);
+	    value = Getattr(p, "type");
 	  qvalue = Swig_symbol_typedef_reduce(value, tsdecl);
 	  dvalue = Swig_symbol_type_qualify(qvalue, tsdecl);
 	  if (SwigType_istemplate(dvalue)) {
@@ -334,7 +338,7 @@ int Swig_cparse_template_expand(Node *n, String *rname, ParmList *tparms, Symtab
 	  {
 	    Parm *rp = nextSibling(p);
 	    while (rp) {
-	      String *rvalue = Getattr(rp, k_value);
+	      String *rvalue = Getattr(rp, "value");
 	      if (rvalue) {
 		Replace(rvalue, name, dvalue, DOH_REPLACE_ID);
 	      }
@@ -393,7 +397,7 @@ int Swig_cparse_template_expand(Node *n, String *rname, ParmList *tparms, Symtab
 
   /* Patch bases */
   {
-    List *bases = Getattr(n, k_baselist);
+    List *bases = Getattr(n, "baselist");
     if (bases) {
       Iterator b;
       for (b = First(bases); b.item; b = Next(b)) {
@@ -411,7 +415,7 @@ int Swig_cparse_template_expand(Node *n, String *rname, ParmList *tparms, Symtab
   Delete(tname);
   Delete(templateargs);
 
-  /*  set_nodeType(n,k_template); */
+  /*  set_nodeType(n,"template"); */
   return 0;
 }
 
@@ -429,6 +433,7 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
   Parm *p;
   Parm *parms;
   Parm *targs;
+  ParmList *expandedparms;
 
   tname = Copy(name);
   parms = CopyParmList(tparms);
@@ -438,26 +443,28 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
 
   /* Add default values from generic template */
   if (templ) {
-    Symtab *tsdecl = Getattr(templ, k_symsymtab);
+    Symtab *tsdecl = Getattr(templ, "sym:symtab");
 
-    targs = Getattr(templ, k_templateparms);
-    Swig_symbol_template_defargs(parms, targs, tscope, tsdecl);
+    targs = Getattr(templ, "templateparms");
+    expandedparms = Swig_symbol_template_defargs(parms, targs, tscope, tsdecl);
+  } else {
+    expandedparms = parms;
   }
 
 
   /* reduce the typedef */
-  p = parms;
+  p = expandedparms;
   while (p) {
-    SwigType *ty = Getattr(p, k_type);
+    SwigType *ty = Getattr(p, "type");
     if (ty) {
       SwigType *nt = Swig_symbol_type_qualify(ty, tscope);
-      Setattr(p, k_type, nt);
+      Setattr(p, "type", nt);
       Delete(nt);
     }
     p = nextSibling(p);
   }
 
-  SwigType_add_template(tname, parms);
+  SwigType_add_template(tname, expandedparms);
 
   if (template_debug) {
     Printf(stdout, "\n%s:%d: template_debug: Searching for %s\n", cparse_file, cparse_line, tname);
@@ -472,7 +479,7 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
     n = Swig_symbol_clookup_local(tname, 0);
     if (!n) {
       SwigType *rname = Swig_symbol_typedef_reduce(tname, tscope);
-      if (!StringEqual(rname, tname)) {
+      if (!Equal(rname, tname)) {
 	if (template_debug) {
 	  Printf(stdout, "    searching: '%s' (exact specialization)\n", rname);
 	}
@@ -482,15 +489,15 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
     }
     if (n) {
       Node *tn;
-      String *nodeType = Getattr(n, k_nodetype);
-      if (StringEqual(nodeType, k_template))
+      String *nodeType = nodeType(n);
+      if (Equal(nodeType, "template"))
 	goto success;
-      tn = Getattr(n, k_template);
+      tn = Getattr(n, "template");
       if (tn) {
 	n = tn;
 	goto success;		/* Previously wrapped by a template return that */
       }
-      Swig_error(cparse_file, cparse_line, "'%s' is not defined as a template. (%s)\n", name, Getattr(n, k_nodetype));
+      Swig_error(cparse_file, cparse_line, "'%s' is not defined as a template. (%s)\n", name, nodeType(n));
       Delete(tname);
       Delete(parms);
       return 0;			/* Found a match, but it's not a template of any kind. */
@@ -506,9 +513,9 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
   p = parms;
   while (p) {
     String *t;
-    t = Getattr(p, k_type);
+    t = Getattr(p, "type");
     if (!t)
-      t = Getattr(p, k_value);
+      t = Getattr(p, "value");
     if (t) {
       String *ty = Swig_symbol_typedef_reduce(t, tscope);
       String *tb = SwigType_base(ty);
@@ -537,7 +544,7 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
     String *ss;
     Iterator pi;
 
-    partials = Getattr(templ, k_partials);
+    partials = Getattr(templ, "partials");
     if (partials) {
       for (pi = First(partials); pi.item; pi = Next(pi)) {
 	ss = Copy(pi.item);
@@ -546,9 +553,9 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
 	while (p) {
 	  String *t, *tn;
 	  sprintf(tmp, "$%d", i);
-	  t = Getattr(p, k_type);
+	  t = Getattr(p, "type");
 	  if (!t)
-	    t = Getattr(p, k_value);
+	    t = Getattr(p, "value");
 	  if (t) {
 	    String *ty = Swig_symbol_typedef_reduce(t, tscope);
 	    tn = SwigType_base(ty);
@@ -562,7 +569,7 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
 	if (template_debug) {
 	  Printf(stdout, "    searching: '%s' (partial specialization - %s)\n", ss, pi.item);
 	}
-	if ((StringEqual(ss, tname)) || (StringEqual(ss, rname))) {
+	if ((Equal(ss, tname)) || (Equal(ss, rname))) {
 	  Append(mpartials, pi.item);
 	}
 	Delete(ss);
@@ -580,7 +587,7 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
     if (Len(mpartials) > 1) {
       if (n) {
 	Swig_warning(WARN_PARSE_TEMPLATE_AMBIG, cparse_file, cparse_line, "Instantiation of template '%s' is ambiguous,\n", SwigType_namestr(tname));
-	Swig_warning(WARN_PARSE_TEMPLATE_AMBIG, Getfile(n), Getline(n), "  instantiation '%s' is used.\n", SwigType_namestr(Getattr(n, k_name)));
+	Swig_warning(WARN_PARSE_TEMPLATE_AMBIG, Getfile(n), Getline(n), "  instantiation '%s' is used.\n", SwigType_namestr(Getattr(n, "name")));
       }
     }
   }
@@ -591,8 +598,8 @@ static Node *template_locate(String *name, Parm *tparms, Symtab *tscope) {
   if (!n) {
     Swig_error(cparse_file, cparse_line, "Template '%s' undefined.\n", name);
   } else if (n) {
-    String *nodeType = Getattr(n, k_nodetype);
-    if (!StringEqual(nodeType, k_template)) {
+    String *nodeType = nodeType(n);
+    if (!Equal(nodeType, "template")) {
       Swig_error(cparse_file, cparse_line, "'%s' is not defined as a template. (%s)\n", name, nodeType);
       n = 0;
     }
@@ -623,10 +630,10 @@ Node *Swig_cparse_template_locate(String *name, Parm *tparms, Symtab *tscope) {
   Node *n = template_locate(name, tparms, tscope);	/* this function does what we want for templated classes */
 
   if (n) {
-    String *nodeType = Getattr(n, k_nodetype);
+    String *nodeType = nodeType(n);
     int isclass = 0;
-    assert(StringEqual(nodeType, k_template));
-    isclass = (StringEqual(Getattr(n, k_templatetype), k_class));
+    assert(Equal(nodeType, "template"));
+    isclass = (Equal(Getattr(n, "templatetype"), "class"));
     if (!isclass) {
       /* If not a templated class we must have a templated function.
          The template found is not necessarily the one we want when dealing with templated
@@ -641,13 +648,13 @@ Node *Swig_cparse_template_locate(String *name, Parm *tparms, Symtab *tscope) {
 
       n = Swig_symbol_clookup_local(name, 0);
       while (n) {
-	Parm *tparmsfound = Getattr(n, k_templateparms);
+	Parm *tparmsfound = Getattr(n, "templateparms");
 	if (ParmList_len(tparms) == ParmList_len(tparmsfound)) {
 	  /* successful match */
 	  break;
 	}
 	/* repeat until we find a match with correct number of templated parameters */
-	n = Getattr(n, k_symnextSibling);
+	n = Getattr(n, "sym:nextSibling");
       }
 
       if (!n) {
