@@ -7,7 +7,7 @@
  * ALLEGROCL language module for SWIG.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_allegrocl_cxx[] = "$Id: allegrocl.cxx 10162 2007-11-21 21:33:42Z mutandiz $";
+char cvsroot_allegrocl_cxx[] = "$Id: allegrocl.cxx 10576 2008-06-24 20:12:08Z wsfulton $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -1597,8 +1597,6 @@ int ALLEGROCL::top(Node *n) {
   Printf(f_cl, "%s\n", f_clhead);
   Printf(f_cl, "%s\n", f_clwrap);
 
-  Printf(stderr, "All done now!\n");
-
   Close(f_cl);
   Delete(f_cl);			// Delete the handle, not the file
   Delete(f_clhead);
@@ -2273,7 +2271,7 @@ int ALLEGROCL::emit_dispatch_defun(Node *n) {
   return SWIG_OK;
 }
 
-int ALLEGROCL::emit_defun(Node *n, File *f_cl) {
+int ALLEGROCL::emit_defun(Node *n, File *fcl) {
 #ifdef ALLEGROCL_WRAP_DEBUG
   Printf(stderr, "emit_defun: ENTER... ");
 #endif
@@ -2295,7 +2293,7 @@ int ALLEGROCL::emit_defun(Node *n, File *f_cl) {
   Wrapper *wrap = NewWrapper();
   Swig_typemap_attach_parms("lin", pl, wrap);
   // Swig_typemap_attach_parms("ffitype", pl, wrap);
-  Swig_typemap_lookup_new("lout", n, "result", 0);
+  Swig_typemap_lookup("lout", n, "result", 0);
 
   SwigType *result_type = Swig_cparse_type(Getattr(n, "tmap:ctype"));
   // prime the pump, with support for OUTPUT, INOUT typemaps.
@@ -2309,27 +2307,27 @@ int ALLEGROCL::emit_defun(Node *n, File *f_cl) {
   if (Generate_Wrapper) {
     String *extra_parms = id_converter_arguments(n)->noname_str();
     if (Getattr(n, "sym:overloaded"))
-      Printf(f_cl, "(swig-defmethod (\"%s\" \"%s\"%s)\n", funcname, mangled_name, extra_parms);
+      Printf(fcl, "(swig-defmethod (\"%s\" \"%s\"%s)\n", funcname, mangled_name, extra_parms);
     else
-      Printf(f_cl, "(swig-defun (\"%s\" \"%s\"%s)\n", funcname, mangled_name, extra_parms);
+      Printf(fcl, "(swig-defun (\"%s\" \"%s\"%s)\n", funcname, mangled_name, extra_parms);
     Delete(extra_parms);
   }
   // Just C
   else {
-    Printf(f_cl, "(swig-defun (\"%s\" \"%s\")\n", funcname, Generate_Wrapper ? mangled_name : funcname);
+    Printf(fcl, "(swig-defun (\"%s\" \"%s\")\n", funcname, Generate_Wrapper ? mangled_name : funcname);
   }
 
   //////////////////////////////////////
   // Lisp foreign call parameter list //
   //////////////////////////////////////
-  Printf(f_cl, "  (");
+  Printf(fcl, "  (");
 
   /* Special cases */
 
   if (ParmList_len(pl) == 0) {
-    Printf(f_cl, ":void");
+    Printf(fcl, ":void");
 /*  } else if (any_varargs(pl)) {
-    Printf(f_cl, "#| varargs |#");
+    Printf(fcl, "#| varargs |#");
     varargs=1; */
   } else {
     String *largs = NewString("");
@@ -2339,7 +2337,7 @@ int ALLEGROCL::emit_defun(Node *n, File *f_cl) {
       SwigType *argtype = Swig_cparse_type(Getattr(p, "tmap:ctype"));
 
       if (!first) {
-	Printf(f_cl, "\n   ");
+	Printf(fcl, "\n   ");
       }
 
       if (SwigType_isvarargs(argtype)) {
@@ -2395,7 +2393,7 @@ int ALLEGROCL::emit_defun(Node *n, File *f_cl) {
 	// if this parameter has been removed from the C/++ wrapper
 	// it shouldn't be in the lisp wrapper either.
 	if (!checkAttribute(p, "tmap:in:numinputs", "0")) {
-	  Printf(f_cl, "(%s %s %s %s %s)",
+	  Printf(fcl, "(%s %s %s %s %s)",
 		 // parms in the ff wrapper, but not in the lisp wrapper.
 		 (checkAttribute(p, "tmap:lin:numinputs", "0") ? ":p-" : ":p+"), argname, dispatchtype, ffitype, lisptype);
 
@@ -2481,12 +2479,12 @@ int ALLEGROCL::emit_defun(Node *n, File *f_cl) {
   Replaceall(wrap->code, "$ldestructor", ldestructor);
   Delete(ldestructor);
 
-  Printf(f_cl, ")\n");		/* finish arg list */
+  Printf(fcl, ")\n");		/* finish arg list */
 
   /////////////////////////////////////////////////////
   // Lisp foreign call return type and optimizations //
   /////////////////////////////////////////////////////
-  Printf(f_cl, "  (:returning (%s %s)", compose_foreign_type(result_type), get_lisp_type(Getattr(n, "type"), "result"));
+  Printf(fcl, "  (:returning (%s %s)", compose_foreign_type(result_type), get_lisp_type(Getattr(n, "type"), "result"));
 
   for (Iterator option = First(n); option.item; option = Next(option)) {
     if (Strncmp("feature:ffargs:", option.key, 15))
@@ -2496,12 +2494,12 @@ int ALLEGROCL::emit_defun(Node *n, File *f_cl) {
     Replaceall(option_name, "_", "-");
 
     // TODO: varargs vs call-direct ?
-    Printf(f_cl, "\n   %s %s", option_name, option_val);
+    Printf(fcl, "\n   %s %s", option_name, option_val);
 
     Delete(option_name);
   }
 
-  Printf(f_cl, ")\n  %s)\n\n", wrap->code);
+  Printf(fcl, ")\n  %s)\n\n", wrap->code);
   // Wrapper_print(wrap, stderr);
 
   Delete(result_type);
@@ -2519,9 +2517,9 @@ int ALLEGROCL::emit_defun(Node *n, File *f_cl) {
 int ALLEGROCL::functionWrapper(Node *n) {
 
   ParmList *parms = CopyParmList(Getattr(n, "parms"));
-  Wrapper *wrap = NewWrapper();
+  Wrapper *f = NewWrapper();
 
-  String *raw_return_type = Swig_typemap_lookup_new("ctype", n, "", 0);
+  String *raw_return_type = Swig_typemap_lookup("ctype", n, "", 0);
   SwigType *return_type = Swig_cparse_type(raw_return_type);
   SwigType *resolved = SwigType_typedef_resolve_all(return_type);
   int is_void_return = (Cmp(resolved, "void") == 0);
@@ -2530,18 +2528,18 @@ int ALLEGROCL::functionWrapper(Node *n) {
 
   if (!is_void_return) {
     String *lresult_init = NewStringf("= (%s)0", raw_return_type);
-    Wrapper_add_localv(wrap, "lresult",
+    Wrapper_add_localv(f, "lresult",
 		       SwigType_lstr(SwigType_ltype(return_type), "lresult"),
 		       lresult_init, NIL);
     Delete(lresult_init);
   }
   // Emit all of the local variables for holding arguments.
-  emit_args(Getattr(n, "type"), parms, wrap);
+  emit_parameter_variables(parms, f);
 
   // Attach the standard typemaps 
-  Swig_typemap_attach_parms("ctype", parms, wrap);
-  Swig_typemap_attach_parms("lin", parms, wrap);
-  emit_attach_parmmaps(parms, wrap);
+  Swig_typemap_attach_parms("ctype", parms, f);
+  Swig_typemap_attach_parms("lin", parms, f);
+  emit_attach_parmmaps(parms, f);
 
   String *mangled = mangle_name(n);
   Node *overloaded = Getattr(n, "sym:overloaded");
@@ -2564,7 +2562,7 @@ int ALLEGROCL::functionWrapper(Node *n) {
 	emit_buffered_defuns(n);
 	emit_dispatch_defun(n);
       }
-      DelWrapper(wrap);
+      DelWrapper(f);
       return SWIG_OK;
     }
   }
@@ -2611,7 +2609,7 @@ int ALLEGROCL::functionWrapper(Node *n) {
       // canThrow(n, "in", p);
       Replaceall(parm_code, "$input", arg);
       Setattr(p, "emit:input", arg);
-      Printf(wrap->code, "%s\n", parm_code);
+      Printf(f->code, "%s\n", parm_code);
       p = Getattr(p, "tmap:in:next");
     }
 
@@ -2621,28 +2619,30 @@ int ALLEGROCL::functionWrapper(Node *n) {
 
   // Emit the function definition
   String *signature = SwigType_str(return_type, name_and_parms);
-  Printf(wrap->def, "EXPORT %s {", signature);
+  Printf(f->def, "EXPORT %s {", signature);
   if (CPlusPlus)
-    Printf(wrap->code, "  try {\n");
-  emit_action(n, wrap);
-  if (!is_void_return) {
-    String *result_convert = Swig_typemap_lookup_new("out", n, "result", 0);
-    Replaceall(result_convert, "$result", "lresult");
-    Printf(wrap->code, "%s\n", result_convert);
-    Printf(wrap->code, "    return lresult;\n");
-    Delete(result_convert);
-  }
+    Printf(f->code, "  try {\n");
+
+  String *actioncode = emit_action(n);
+
+  String *result_convert = Swig_typemap_lookup_out("out", n, "result", f, actioncode);
+  Replaceall(result_convert, "$result", "lresult");
+  Printf(f->code, "%s\n", result_convert);
+  Printf(f->code, "    return lresult;\n");
+  Delete(result_convert);
+  emit_return_variable(n, Getattr(n, "type"), f);
+
   if (CPlusPlus) {
-    Printf(wrap->code, "  } catch (...) {\n");
+    Printf(f->code, "  } catch (...) {\n");
     if (!is_void_return)
-      Printf(wrap->code, "    return (%s)0;\n", raw_return_type);
-    Printf(wrap->code, "  }\n");
+      Printf(f->code, "    return (%s)0;\n", raw_return_type);
+    Printf(f->code, "  }\n");
   }
-  Printf(wrap->code, "}\n");
+  Printf(f->code, "}\n");
 
   /* print this when in C mode? make this a command-line arg? */
   if (Generate_Wrapper)
-    Wrapper_print(wrap, f_cxx);
+    Wrapper_print(f, f_cxx);
 
   String *f_buffer = NewString("");
 
@@ -2658,7 +2658,7 @@ int ALLEGROCL::functionWrapper(Node *n) {
     }
   }
 
-  DelWrapper(wrap);
+  DelWrapper(f);
 
   return SWIG_OK;
 }
@@ -2935,11 +2935,9 @@ int ALLEGROCL::classHandler(Node *n) {
 #endif
 
   if (Generate_Wrapper)
-	  return cppClassHandler(n);
+    return cppClassHandler(n);
   else
-	  return cClassHandler(n);
-
-  return SWIG_OK;
+    return cClassHandler(n);
 }
 
 int ALLEGROCL::cClassHandler(Node *n) {
