@@ -7,7 +7,7 @@
  * CHICKEN language module for SWIG.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_chicken_cxx[] = "$Id: chicken.cxx 10054 2007-10-26 23:08:34Z wuzzeb $";
+char cvsroot_chicken_cxx[] = "$Id: chicken.cxx 10562 2008-06-23 21:14:53Z wsfulton $";
 
 #include "swigmod.h"
 
@@ -329,7 +329,6 @@ int CHICKEN::functionWrapper(Node *n) {
   Parm *p;
   int i;
   String *wname;
-  String *source;
   Wrapper *f;
   String *mangle = NewString("");
   String *get_pointers;
@@ -368,7 +367,7 @@ int CHICKEN::functionWrapper(Node *n) {
   Wrapper_add_local(f, "resultobj", "C_word resultobj");
 
   /* Write code to extract function parameters. */
-  emit_args(d, l, f);
+  emit_parameter_variables(l, f);
 
   /* Attach the standard typemaps */
   emit_attach_parmmaps(l, f);
@@ -398,8 +397,6 @@ int CHICKEN::functionWrapper(Node *n) {
     SwigType *pt = Getattr(p, "type");
     String *ln = Getattr(p, "lname");
 
-    source = NewStringf("scm%d", i + 1);
-
     Printf(f->def, ", C_word scm%d", i + 1);
     Printf(declfunc, ",C_word");
 
@@ -407,6 +404,7 @@ int CHICKEN::functionWrapper(Node *n) {
     if ((tm = Getattr(p, "tmap:in"))) {
       String *parse = Getattr(p, "tmap:in:parse");
       if (!parse) {
+        String *source = NewStringf("scm%d", i + 1);
 	Replaceall(tm, "$source", source);
 	Replaceall(tm, "$target", ln);
 	Replaceall(tm, "$input", source);
@@ -445,20 +443,15 @@ int CHICKEN::functionWrapper(Node *n) {
 	    }
 	  }
 	}
-
-      } else {
+        Delete(source);
       }
 
-
       p = Getattr(p, "tmap:in:next");
       continue;
     } else {
       Swig_warning(WARN_TYPEMAP_IN_UNDEF, input_file, line_number, "Unable to use type %s as a function argument.\n", SwigType_str(pt, 0));
       break;
     }
-
-    Delete(source);
-    p = nextSibling(p);
   }
 
   /* finish argument marshalling */
@@ -501,9 +494,6 @@ int CHICKEN::functionWrapper(Node *n) {
     }
   }
 
-  /* Emit the function call */
-  emit_action(n, f);
-
   /* Insert argument output code */
   have_argout = 0;
   for (p = l; p;) {
@@ -512,7 +502,7 @@ int CHICKEN::functionWrapper(Node *n) {
       if (!have_argout) {
 	have_argout = 1;
 	// Print initial argument output code
-	Printf(f->code, "SWIG_Chicken_SetupArgout\n");
+	Printf(argout, "SWIG_Chicken_SetupArgout\n");
       }
 
       Replaceall(tm, "$source", Getattr(p, "lname"));
@@ -526,8 +516,13 @@ int CHICKEN::functionWrapper(Node *n) {
     }
   }
 
+  Setattr(n, "wrap:name", wname);
+
+  /* Emit the function call */
+  String *actioncode = emit_action(n);
+
   /* Return the function value */
-  if ((tm = Swig_typemap_lookup_new("out", n, "result", 0))) {
+  if ((tm = Swig_typemap_lookup_out("out", n, "result", f, actioncode))) {
     Replaceall(tm, "$source", "result");
     Replaceall(tm, "$target", "resultobj");
     Replaceall(tm, "$result", "resultobj");
@@ -545,6 +540,7 @@ int CHICKEN::functionWrapper(Node *n) {
   } else {
     Swig_warning(WARN_TYPEMAP_OUT_UNDEF, input_file, line_number, "Unable to use return type %s in function %s.\n", SwigType_str(d, 0), name);
   }
+  emit_return_variable(n, d, f);
 
   /* Insert the argumetn output code */
   Printv(f->code, argout, NIL);
@@ -554,14 +550,14 @@ int CHICKEN::functionWrapper(Node *n) {
 
   /* Look to see if there is any newfree cleanup code */
   if (GetFlag(n, "feature:new")) {
-    if ((tm = Swig_typemap_lookup_new("newfree", n, "result", 0))) {
+    if ((tm = Swig_typemap_lookup("newfree", n, "result", 0))) {
       Replaceall(tm, "$source", "result");
       Printf(f->code, "%s\n", tm);
     }
   }
 
   /* See if there is any return cleanup code */
-  if ((tm = Swig_typemap_lookup_new("ret", n, "result", 0))) {
+  if ((tm = Swig_typemap_lookup("ret", n, "result", 0))) {
     Replaceall(tm, "$source", "result");
     Printf(f->code, "%s\n", tm);
   }
@@ -603,8 +599,6 @@ int CHICKEN::functionWrapper(Node *n) {
   Printv(f_wrappers, "static ", declfunc, " C_noret;\n", NIL);
   Wrapper_print(f, f_wrappers);
 
-  Setattr(n, "wrap:name", wname);
-
   /* Now register the function with the interpreter.   */
   if (!Getattr(n, "sym:overloaded")) {
     if (exporting_destructor && !no_collection) {
@@ -709,6 +703,8 @@ int CHICKEN::variableWrapper(Node *n) {
   if (overname) {
     Append(wname, overname);
   }
+  Setattr(n, "wrap:name", wname);
+
   // Check for interrupts
   Printv(f->code, "C_trace(\"", scmname, "\");\n", NIL);
 
@@ -724,12 +720,12 @@ int CHICKEN::variableWrapper(Node *n) {
     /* Check for a setting of the variable value */
     if (!GetFlag(n, "feature:immutable")) {
       Printf(f->code, "if (argc > 2) {\n");
-      if ((tm = Swig_typemap_lookup_new("varin", n, name, 0))) {
+      if ((tm = Swig_typemap_lookup("varin", n, name, 0))) {
 	Replaceall(tm, "$source", "value");
 	Replaceall(tm, "$target", name);
 	Replaceall(tm, "$input", "value");
 	/* Printv(f->code, tm, "\n",NIL); */
-	emit_action_code(n, f, tm);
+	emit_action_code(n, f->code, tm);
       } else {
 	Swig_warning(WARN_TYPEMAP_VARIN_UNDEF, input_file, line_number, "Unable to set variable of type %s.\n", SwigType_str(t, 0));
       }
@@ -745,13 +741,13 @@ int CHICKEN::variableWrapper(Node *n) {
 
     // Now return the value of the variable - regardless
     // of evaluating or setting.
-    if ((tm = Swig_typemap_lookup_new("varout", n, name, 0))) {
+    if ((tm = Swig_typemap_lookup("varout", n, name, 0))) {
       Replaceall(tm, "$source", varname);
       Replaceall(tm, "$varname", varname);
       Replaceall(tm, "$target", "resultobj");
       Replaceall(tm, "$result", "resultobj");
       /* Printf(f->code, "%s\n", tm); */
-      emit_action_code(n, f, tm);
+      emit_action_code(n, f->code, tm);
     } else {
       Swig_warning(WARN_TYPEMAP_VAROUT_UNDEF, input_file, line_number, "Unable to read variable of type %s\n", SwigType_str(t, 0));
     }
@@ -878,7 +874,7 @@ int CHICKEN::constantWrapper(Node *n) {
   if (SwigType_type(t) == T_MPOINTER) {
     Printf(f_header, "static %s = %s;\n", SwigType_str(t, source), rvalue);
   } else {
-    if ((tm = Swig_typemap_lookup_new("constcode", n, name, 0))) {
+    if ((tm = Swig_typemap_lookup("constcode", n, name, 0))) {
       Replaceall(tm, "$source", rvalue);
       Replaceall(tm, "$target", source);
       Replaceall(tm, "$result", source);
@@ -907,6 +903,7 @@ int CHICKEN::constantWrapper(Node *n) {
 
   if (1 || (SwigType_type(t) != T_USER) || (isPointer(t))) {
 
+    Setattr(n, "wrap:name", wname);
     Printv(f->def, "static ", "void ", wname, "(C_word, C_word, C_word) C_noret;\n", NIL);
 
     Printv(f->def, "static ", "void ", wname, "(C_word argc, C_word closure, " "C_word continuation) {\n", NIL);
@@ -916,14 +913,14 @@ int CHICKEN::constantWrapper(Node *n) {
     Printf(f->code, "if (argc!=2) C_bad_argc(argc,2);\n");
 
     // Return the value of the variable
-    if ((tm = Swig_typemap_lookup_new("varout", n, name, 0))) {
+    if ((tm = Swig_typemap_lookup("varout", n, name, 0))) {
 
       Replaceall(tm, "$source", source);
       Replaceall(tm, "$varname", source);
       Replaceall(tm, "$target", "resultobj");
       Replaceall(tm, "$result", "resultobj");
       /* Printf(f->code, "%s\n", tm); */
-      emit_action_code(n, f, tm);
+      emit_action_code(n, f->code, tm);
     } else {
       Swig_warning(WARN_TYPEMAP_VAROUT_UNDEF, input_file, line_number, "Unable to read variable of type %s\n", SwigType_str(t, 0));
     }
@@ -1506,7 +1503,7 @@ int CHICKEN::validIdentifier(String *s) {
   /* ------------------------------------------------------------
    * closNameMapping()
    * Maps the identifier from C++ to the CLOS based on command 
-   * line paramaters and such.
+   * line parameters and such.
    * If class_name = "" that means the mapping is for a function or
    * variable not attached to any class.
    * ------------------------------------------------------------ */
