@@ -7,7 +7,7 @@
  * Guile language module for SWIG.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_guile_cxx[] = "$Id: guile.cxx 10003 2007-10-17 21:42:11Z wsfulton $";
+char cvsroot_guile_cxx[] = "$Id: guile.cxx 10562 2008-06-23 21:14:53Z wsfulton $";
 
 #include "swigmod.h"
 
@@ -687,7 +687,7 @@ public:
     Replaceall(proc_name, "_", "-");
 
     /* Emit locals etc. into f->code; figure out which args to ignore */
-    emit_args(d, l, f);
+    emit_parameter_variables(l, f);
 
     /* Attach the standard typemaps */
     emit_attach_parmmaps(l, f);
@@ -702,25 +702,6 @@ public:
     Wrapper_add_local(f, "gswig_result", "SCM gswig_result");
     Wrapper_add_local(f, "gswig_list_p", "SWIGUNUSED int gswig_list_p = 0");
 
-    /* Get the output typemap so we can start generating documentation.  Don't
-       worry, the returned string is saved as 'tmap:out' */
-
-    Swig_typemap_lookup_new("out", n, "result", 0);
-
-    if ((tm = Getattr(n, "tmap:out:doc"))) {
-      Printv(returns, tm, NIL);
-      if (Len(tm) > 0)
-	num_results = 1;
-      else
-	num_results = 0;
-    } else {
-      String *s = SwigType_str(d, 0);
-      Chop(s);
-      Printf(returns, "<%s>", s);
-      Delete(s);
-      num_results = 1;
-    }
-
     /* Open prototype and signature */
 
     Printv(f->def, "static SCM\n", wname, " (", NIL);
@@ -830,6 +811,7 @@ public:
     /* Pass output arguments back to the caller. */
 
     /* Insert argument output code */
+    String *returns_argout = NewString("");
     for (p = l; p;) {
       if ((tm = Getattr(p, "tmap:argout"))) {
 	Replaceall(tm, "$source", Getattr(p, "lname"));
@@ -838,7 +820,7 @@ public:
 	Replaceall(tm, "$input", Getattr(p, "emit:input"));
 	Printv(outarg, tm, "\n", NIL);
 	if (procdoc) {
-	  if (handle_documentation_typemap(returns, ", ", p, "tmap:argout:doc", "$NAME (of type $type)")) {
+	  if (handle_documentation_typemap(returns_argout, ", ", p, "tmap:argout:doc", "$NAME (of type $type)")) {
 	    /* A documentation typemap that is not the empty string
 	       indicates that a value is returned to Scheme. */
 	    num_results++;
@@ -881,13 +863,14 @@ public:
     // Now write code to make the function call
     if (!use_scm_interface)
       Printv(f->code, tab4, "gh_defer_ints();\n", NIL);
-    emit_action(n, f);
+
+    String *actioncode = emit_action(n);
+
     if (!use_scm_interface)
-      Printv(f->code, tab4, "gh_allow_ints();\n", NIL);
+      Printv(actioncode, tab4, "gh_allow_ints();\n", NIL);
 
     // Now have return value, figure out what to do with it.
-
-    if ((tm = Getattr(n, "tmap:out"))) {
+    if ((tm = Swig_typemap_lookup_out("out", n, "result", f, actioncode))) {
       Replaceall(tm, "$result", "gswig_result");
       Replaceall(tm, "$target", "gswig_result");
       Replaceall(tm, "$source", "result");
@@ -899,6 +882,24 @@ public:
     } else {
       throw_unhandled_guile_type_error(d);
     }
+    emit_return_variable(n, d, f);
+
+    // Documentation
+    if ((tm = Getattr(n, "tmap:out:doc"))) {
+      Printv(returns, tm, NIL);
+      if (Len(tm) > 0)
+	num_results = 1;
+      else
+	num_results = 0;
+    } else {
+      String *s = SwigType_str(d, 0);
+      Chop(s);
+      Printf(returns, "<%s>", s);
+      Delete(s);
+      num_results = 1;
+    }
+    Append(returns, returns_argout);
+
 
     // Dump the argument output code
     Printv(f->code, outarg, NIL);
@@ -909,13 +910,13 @@ public:
     // Look for any remaining cleanup
 
     if (GetFlag(n, "feature:new")) {
-      if ((tm = Swig_typemap_lookup_new("newfree", n, "result", 0))) {
+      if ((tm = Swig_typemap_lookup("newfree", n, "result", 0))) {
 	Replaceall(tm, "$source", "result");
 	Printv(f->code, tm, "\n", NIL);
       }
     }
     // Free any memory allocated by the function being wrapped..
-    if ((tm = Swig_typemap_lookup_new("ret", n, "result", 0))) {
+    if ((tm = Swig_typemap_lookup("ret", n, "result", 0))) {
       Replaceall(tm, "$source", "result");
       Printv(f->code, tm, "\n", NIL);
     }
@@ -1123,6 +1124,7 @@ public:
     Delete(method_signature);
     Delete(primitive_args);
     Delete(doc_body);
+    Delete(returns_argout);
     Delete(returns);
     Delete(tmp);
     Delete(scheme_arg_names);
@@ -1162,6 +1164,7 @@ public:
     // Build the name for scheme.
     proc_name = NewString(iname);
     Replaceall(proc_name, "_", "-");
+    Setattr(n, "wrap:name", proc_name);
 
     if (1 || (SwigType_type(t) != T_USER) || (is_a_pointer(t))) {
 
@@ -1176,12 +1179,12 @@ public:
       if (!GetFlag(n, "feature:immutable")) {
 	/* Check for a setting of the variable value */
 	Printf(f->code, "if (s_0 != SCM_UNDEFINED) {\n");
-	if ((tm = Swig_typemap_lookup_new("varin", n, name, 0))) {
+	if ((tm = Swig_typemap_lookup("varin", n, name, 0))) {
 	  Replaceall(tm, "$source", "s_0");
 	  Replaceall(tm, "$input", "s_0");
 	  Replaceall(tm, "$target", name);
 	  /* Printv(f->code,tm,"\n",NIL); */
-	  emit_action_code(n, f, tm);
+	  emit_action_code(n, f->code, tm);
 	} else {
 	  throw_unhandled_guile_type_error(t);
 	}
@@ -1190,12 +1193,12 @@ public:
       // Now return the value of the variable (regardless
       // of evaluating or setting)
 
-      if ((tm = Swig_typemap_lookup_new("varout", n, name, 0))) {
+      if ((tm = Swig_typemap_lookup("varout", n, name, 0))) {
 	Replaceall(tm, "$source", name);
 	Replaceall(tm, "$target", "gswig_result");
 	Replaceall(tm, "$result", "gswig_result");
 	/* Printv(f->code,tm,"\n",NIL); */
-	emit_action_code(n, f, tm);
+	emit_action_code(n, f->code, tm);
       } else {
 	throw_unhandled_guile_type_error(t);
       }
@@ -1386,7 +1389,7 @@ public:
       rvalue = NewString(value);
     }
 
-    if ((tm = Swig_typemap_lookup_new("constant", n, name, 0))) {
+    if ((tm = Swig_typemap_lookup("constant", n, name, 0))) {
       Replaceall(tm, "$source", rvalue);
       Replaceall(tm, "$value", rvalue);
       Replaceall(tm, "$target", name);
@@ -1646,7 +1649,7 @@ public:
   /* ------------------------------------------------------------
    * goopsNameMapping()
    * Maps the identifier from C++ to the GOOPS based * on command 
-   * line paramaters and such.
+   * line parameters and such.
    * If class_name = "" that means the mapping is for a function or
    * variable not attached to any class.
    * ------------------------------------------------------------ */
