@@ -7,7 +7,7 @@
  * Header file for the SWIG core.
  * ----------------------------------------------------------------------------- */
 
-/* $Id: swig.h 9982 2007-10-12 21:31:22Z wsfulton $ */
+/* $Id: swig.h 10453 2008-05-15 21:18:44Z wsfulton $ */
 
 #ifndef SWIGCORE_H_
 #define SWIGCORE_H_
@@ -111,6 +111,7 @@ extern "C" {
   extern SwigType *SwigType_del_element(SwigType *t);
   extern SwigType *SwigType_add_pointer(SwigType *t);
   extern SwigType *SwigType_add_memberpointer(SwigType *t, const String_or_char *qual);
+  extern SwigType *SwigType_del_memberpointer(SwigType *t);
   extern SwigType *SwigType_del_pointer(SwigType *t);
   extern SwigType *SwigType_add_array(SwigType *t, const String_or_char *size);
   extern SwigType *SwigType_del_array(SwigType *t);
@@ -136,6 +137,7 @@ extern "C" {
   extern SwigType *SwigType_ltype(SwigType *t);
   extern int SwigType_ispointer(SwigType *t);
   extern int SwigType_ispointer_return(SwigType *t);
+  extern int SwigType_isfunctionpointer(SwigType *t);
   extern int SwigType_ismemberpointer(SwigType *t);
   extern int SwigType_isreference(SwigType *t);
   extern int SwigType_isreference_return(SwigType *t);
@@ -151,6 +153,7 @@ extern "C" {
   extern int SwigType_isenum(SwigType *t);
   extern int SwigType_check_decl(SwigType *t, const String_or_char *decl);
   extern SwigType *SwigType_strip_qualifiers(SwigType *t);
+  extern SwigType *SwigType_functionpointer_decompose(SwigType *t);
   extern String *SwigType_base(const SwigType *t);
   extern String *SwigType_namestr(const SwigType *t);
   extern String *SwigType_templateprefix(const SwigType *t);
@@ -169,17 +172,17 @@ extern "C" {
   extern SwigType *SwigType_template_deftype(const SwigType *type, Symtab *tscope);
 
 /* --- Type-system managment --- */
-  extern void SwigType_typesystem_init();
+  extern void SwigType_typesystem_init(void);
   extern int SwigType_typedef(SwigType *type, String_or_char *name);
   extern int SwigType_typedef_class(String_or_char *name);
   extern int SwigType_typedef_using(String_or_char *qname);
-  extern void SwigType_inherit(String *subclass, String *baseclass, String *cast);
+  extern void SwigType_inherit(String *subclass, String *baseclass, String *cast, String *conversioncode);
   extern int SwigType_issubtype(SwigType *subtype, SwigType *basetype);
   extern void SwigType_scope_alias(String *aliasname, Typetab *t);
   extern void SwigType_using_scope(Typetab *t);
   extern void SwigType_new_scope(const String_or_char *name);
   extern void SwigType_inherit_scope(Typetab *scope);
-  extern Typetab *SwigType_pop_scope();
+  extern Typetab *SwigType_pop_scope(void);
   extern Typetab *SwigType_set_scope(Typetab *h);
   extern void SwigType_print_scope(Typetab *t);
   extern SwigType *SwigType_typedef_resolve(SwigType *t);
@@ -197,15 +200,15 @@ extern "C" {
 
 /* --- Symbol table module --- */
 
-  extern void Swig_symbol_init();
+  extern void Swig_symbol_init(void);
   extern void Swig_symbol_setscopename(const String_or_char *name);
-  extern String *Swig_symbol_getscopename();
+  extern String *Swig_symbol_getscopename(void);
   extern String *Swig_symbol_qualifiedscopename(Symtab *symtab);
-  extern Symtab *Swig_symbol_newscope();
+  extern Symtab *Swig_symbol_newscope(void);
   extern Symtab *Swig_symbol_setscope(Symtab *);
   extern Symtab *Swig_symbol_getscope(const String_or_char *symname);
-  extern Symtab *Swig_symbol_current();
-  extern Symtab *Swig_symbol_popscope();
+  extern Symtab *Swig_symbol_current(void);
+  extern Symtab *Swig_symbol_popscope(void);
   extern Node *Swig_symbol_add(String_or_char *symname, Node *node);
   extern void Swig_symbol_cadd(String_or_char *symname, Node *node);
   extern Node *Swig_symbol_clookup(String_or_char *symname, Symtab *tab);
@@ -222,7 +225,7 @@ extern "C" {
   extern String *Swig_symbol_string_qualify(String *s, Symtab *tab);
   extern SwigType *Swig_symbol_typedef_reduce(SwigType *ty, Symtab *tab);
 
-  extern void Swig_symbol_template_defargs(Parm *parms, Parm *targs, Symtab *tscope, Symtab *tsdecl);
+  extern ParmList *Swig_symbol_template_defargs(Parm *parms, Parm *targs, Symtab *tscope, Symtab *tsdecl);
   extern SwigType *Swig_symbol_template_deftype(const SwigType *type, Symtab *tscope);
   extern SwigType *Swig_symbol_template_param_eval(const SwigType *p, Symtab *symtab);
 
@@ -255,7 +258,7 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
   extern String *Swig_name_destroy(const String_or_char *classname);
   extern String *Swig_name_disown(const String_or_char *classname);
 
-  extern void Swig_naming_init();
+  extern void Swig_naming_init(void);
   extern void Swig_name_namewarn_add(String *prefix, String *name, SwigType *decl, Hash *namewrn);
   extern Hash *Swig_name_namewarn_get(Node *n, String *prefix, String *name, SwigType *decl);
   extern void Swig_name_rename_add(String *prefix, String *name, SwigType *decl, Hash *namewrn, ParmList *declaratorparms);
@@ -266,6 +269,8 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
 
   extern String *Swig_name_make(Node *n, String *prefix, String_or_char *cname, SwigType *decl, String *oldname);
   extern String *Swig_name_warning(Node *n, String *prefix, String *name, SwigType *decl);
+  extern String *Swig_name_decl(Node *n);
+  extern String *Swig_name_fulldecl(Node *n);
 
 /* --- parameterized rename functions --- */
 
@@ -273,8 +278,7 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
   extern DOH *Swig_name_object_get(Hash *namehash, String_or_char *prefix, String_or_char *name, SwigType *decl);
   extern void Swig_name_object_inherit(Hash *namehash, String *base, String *derived);
   extern void Swig_features_get(Hash *features, String_or_char *prefix, String_or_char *name, SwigType *decl, Node *n);
-  extern void Swig_feature_set(Hash *features, const String_or_char *name, SwigType *decl, const String_or_char *featurename, String *value,
-			       Hash *featureattribs);
+  extern void Swig_feature_set(Hash *features, const String_or_char *name, SwigType *decl, const String_or_char *featurename, String *value, Hash *featureattribs);
 
 /* --- Misc --- */
   extern char *Swig_copy_string(const char *c);
@@ -294,7 +298,7 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
   extern String *Swig_string_upper(String *s);
   extern String *Swig_string_title(String *s);
 
-  extern void Swig_init();
+  extern void Swig_init(void);
   extern void Swig_warn(const char *filename, int line, const char *msg);
 
   extern int Swig_value_wrapper_mode(int mode);
@@ -341,11 +345,12 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
   extern int Swig_VargetToFunction(Node *n, int flags);
   extern int Swig_VarsetToFunction(Node *n, int flags);
 
-#define  CWRAP_EXTEND             0x01
-#define  CWRAP_SMART_POINTER      0x02
-#define  CWRAP_NATURAL_VAR        0x04
-#define  CWRAP_DIRECTOR_ONE_CALL  0x08
-#define  CWRAP_DIRECTOR_TWO_CALLS 0x10
+#define  CWRAP_EXTEND                 0x01
+#define  CWRAP_SMART_POINTER          0x02
+#define  CWRAP_NATURAL_VAR            0x04
+#define  CWRAP_DIRECTOR_ONE_CALL      0x08
+#define  CWRAP_DIRECTOR_TWO_CALLS     0x10
+#define  CWRAP_ALL_PROTECTED_ACCESS   0x20
 
 /* --- Director Helpers --- */
   extern Node *Swig_methodclass(Node *n);
@@ -354,23 +359,21 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
 
 /* --- Legacy Typemap API (somewhat simplified, ha!) --- */
 
-  extern void Swig_typemap_init();
+  extern void Swig_typemap_init(void);
   extern void Swig_typemap_register(const String_or_char *op, ParmList *pattern, String_or_char *code, ParmList *locals, ParmList *kwargs);
   extern int Swig_typemap_copy(const String_or_char *op, ParmList *srcpattern, ParmList *pattern);
   extern void Swig_typemap_clear(const String_or_char *op, ParmList *pattern);
   extern int Swig_typemap_apply(ParmList *srcpat, ParmList *destpat);
   extern void Swig_typemap_clear_apply(ParmList *pattern);
-  extern void Swig_typemap_debug();
+  extern void Swig_typemap_debug(void);
 
   extern Hash *Swig_typemap_search(const String_or_char *op, SwigType *type, const String_or_char *pname, SwigType **matchtype);
   extern Hash *Swig_typemap_search_multi(const String_or_char *op, ParmList *parms, int *nmatch);
-  extern String *Swig_typemap_lookup(const String_or_char *op, SwigType *type, String_or_char *pname, String_or_char *lname,
-				     String_or_char *source, String_or_char *target, Wrapper *f);
-
-  extern String *Swig_typemap_lookup_new(const String_or_char *op, Node *n, const String_or_char *lname, Wrapper *f);
+  extern String *Swig_typemap_lookup(const String_or_char *op, Node *n, const String_or_char *lname, Wrapper *f);
+  extern String *Swig_typemap_lookup_out(const String_or_char *op, Node *n, const String_or_char *lname, Wrapper *f, String *actioncode);
   extern void Swig_typemap_attach_kwargs(Hash *tm, const String_or_char *op, Parm *p);
-  extern void Swig_typemap_new_scope();
-  extern Hash *Swig_typemap_pop_scope();
+  extern void Swig_typemap_new_scope(void);
+  extern Hash *Swig_typemap_pop_scope(void);
 
   extern void Swig_typemap_attach_parms(const String_or_char *op, ParmList *parms, Wrapper *f);
 
@@ -378,14 +381,19 @@ extern int        ParmList_is_compactdefargs(ParmList *p);
 
   extern void Swig_fragment_register(Node *fragment);
   extern void Swig_fragment_emit(String *name);
+  extern void Swig_fragment_clear(String *section);
 
 /* hacks defined in C++ ! */
-  extern int Swig_director_mode();
+  extern int Swig_director_mode(void);
+  extern int Swig_director_protected_mode(void);
+  extern int Swig_all_protected_mode(void);
   extern void Wrapper_director_mode_set(int);
+  extern void Wrapper_director_protected_mode_set(int);
+  extern void Wrapper_all_protected_mode_set(int);
 
 
 /* -- template init -- */
-  extern void SwigType_template_init();
+  extern void SwigType_template_init(void);
 
 
 #ifdef __cplusplus
