@@ -10,7 +10,7 @@
  * like typedef, namespaces, etc.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_typeobj_c[] = "$Id: typeobj.c 9967 2007-10-08 12:02:56Z olly $";
+char cvsroot_typeobj_c[] = "$Id: typeobj.c 10540 2008-06-21 15:23:02Z wsfulton $";
 
 #include "swig.h"
 #include <ctype.h>
@@ -231,7 +231,7 @@ String *SwigType_parm(SwigType *t) {
  * ----------------------------------------------------------------------------- */
 
 List *SwigType_split(const SwigType *t) {
-  DOH *item;
+  String *item;
   List *list;
   char *c;
   int len;
@@ -253,25 +253,40 @@ List *SwigType_split(const SwigType *t) {
 /* -----------------------------------------------------------------------------
  * SwigType_parmlist()
  *
- * Splits a comma separated list of type components into strings.
+ * Splits a comma separated list of parameters into its component parts
+ * The input is expected to contain the parameter list within () brackets
+ * Returns 0 if no argument list in the input, ie there are no round brackets ()
+ * Returns an empty List if there are no parameters in the () brackets
+ * For example:
+ *
+ *     Foo(std::string,p.f().Bar<(int,double)>)
+ *
+ * returns 2 elements in the list:
+ *    std::string
+ *    p.f().Bar<(int,double)>
  * ----------------------------------------------------------------------------- */
-
+ 
 List *SwigType_parmlist(const String *p) {
-  DOH *item;
+  String *item = 0;
   List *list;
-  char *c, *itemstart;
+  char *c;
+  char *itemstart;
+  int size;
 
+  assert(p);
   c = Char(p);
   while (*c && (*c != '(') && (*c != '.'))
     c++;
-  if (!*c || (*c == '.'))
+  if (!*c)
     return 0;
+  assert(*c != '.'); /* p is expected to contain sub elements of a type */
   c++;
   list = NewList();
   itemstart = c;
   while (*c) {
     if (*c == ',') {
-      item = NewStringWithSize(itemstart, (int) (c - itemstart));
+      size = (int) (c - itemstart);
+      item = NewStringWithSize(itemstart, size);
       Append(list, item);
       Delete(item);
       itemstart = c + 1;
@@ -294,8 +309,11 @@ List *SwigType_parmlist(const String *p) {
     if (*c)
       c++;
   }
-  item = NewStringWithSize(itemstart, (int) (c - itemstart));
-  Append(list, item);
+  size = (int) (c - itemstart);
+  if (size > 0) {
+    item = NewStringWithSize(itemstart, size);
+    Append(list, item);
+  }
   Delete(item);
   return list;
 }
@@ -477,6 +495,38 @@ int SwigType_isqualifier(SwigType *t) {
   return 0;
 }
 
+/* -----------------------------------------------------------------------------
+ *                                Function Pointers
+ * ----------------------------------------------------------------------------- */
+
+int SwigType_isfunctionpointer(SwigType *t) {
+  char *c;
+  if (!t)
+    return 0;
+  c = Char(t);
+  if (strncmp(c, "p.f(", 4) == 0) {
+    return 1;
+  }
+  return 0;
+}
+
+/* -----------------------------------------------------------------------------
+ * SwigType_functionpointer_decompose
+ *
+ * Decompose the function pointer into the parameter list and the return type
+ * t - input and on completion contains the return type
+ * returns the function's parameters
+ * ----------------------------------------------------------------------------- */
+
+SwigType *SwigType_functionpointer_decompose(SwigType *t) {
+  String *p;
+  assert(SwigType_isfunctionpointer(t));
+  p = SwigType_pop(t);
+  Delete(p);
+  p = SwigType_pop(t);
+  return p;
+}
+
 /* -----------------------------------------------------------------------------
  *                                Member Pointers
  *
@@ -804,7 +854,7 @@ SwigType *SwigType_add_template(SwigType *t, ParmList *parms) {
  *
  *     Foo<(p.int)>::bar
  *
- * Results in "Foo"
+ * returns "Foo"
  * ----------------------------------------------------------------------------- */
 
 String *SwigType_templateprefix(const SwigType *t) {
@@ -848,7 +898,12 @@ String *SwigType_templatesuffix(const SwigType *t) {
 /* -----------------------------------------------------------------------------
  * SwigType_templateargs()
  *
- * Returns the template part
+ * Returns the template arguments
+ * For example:
+ *
+ *     Foo<(p.int)>::bar
+ *
+ * returns "<(p.int)>"
  * ----------------------------------------------------------------------------- */
 
 String *SwigType_templateargs(const SwigType *t) {
@@ -882,7 +937,8 @@ String *SwigType_templateargs(const SwigType *t) {
 
 int SwigType_istemplate(const SwigType *t) {
   char *ct = Char(t);
-  if ((ct = strstr(ct, "<(")) && (strstr(ct + 2, ")>")))
+  ct = strstr(ct, "<(");
+  if (ct && (strstr(ct + 2, ")>")))
     return 1;
   return 0;
 }
